summaryrefslogtreecommitdiff
path: root/json-glib/json-gobject.c
diff options
context:
space:
mode:
Diffstat (limited to 'json-glib/json-gobject.c')
-rw-r--r--json-glib/json-gobject.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/json-glib/json-gobject.c b/json-glib/json-gobject.c
index d39088e..34a43c8 100644
--- a/json-glib/json-gobject.c
+++ b/json-glib/json-gobject.c
@@ -839,7 +839,7 @@ json_gobject_deserialize (GType gtype,
* map to a property of the #GObject
*
* Return value: (transfer full): the newly created #JsonNode
* of type %JSON_NODE_OBJECT. Use json_node_free() to free
* the resources allocated by this function
*
* Since: 0.10
@@ -1012,7 +1012,7 @@ json_gobject_to_data (GObject *gobject,
data = json_generator_to_data (gen, length);
g_object_unref (gen);
- json_node_free (root);
+ json_node_unref (root);
return data;
}
@@ -839,7 +839,7 @@ json_gobject_deserialize (GType gtype,
*
* Return value: (transfer full): the newly created #JsonNode
- * of type %JSON_NODE_OBJECT. Use json_node_free() to free
+ * of type %JSON_NODE_OBJECT. Use json_node_unref() to free
* the resources allocated by this function
*